==> qtjambi-xml-debuginfo-macos-6.7.0.jar: sources/QtJambiXml/QDomProcessingInstruction_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomProcessingInstruction(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomProcessingInstruction")
    QDomProcessingInstruction *_ptr = reinterpret_cast<QDomProcessingInstruction *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomProcessingInstruction()
void __qt_construct_QDomProcessingInstruction(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomProcessingInstruction()")
    Q_UNUSED(__java_arguments)
    QDomProcessingInstruction *__qt_this = new(__qtjambi_ptr) QDomProcessingInstruction();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QDomProcessingInstruction::QDomProcessingInstruction()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_initialize_1native__Lio_qt_xml_QDomProcessingInstruction_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomProcessingInstruction::QDomProcessingInstruction()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomProcessingInstruction, sizeof(QDomProcessingInstruction), typeid(QDomProcessingInstruction), false, &deleter_QDomProcessingInstruction, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomProcessingInstruction(QDomProcessingInstruction)
void __qt_construct_QDomProcessingInstruction_cref_QDomProcessingInstruction(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomProcessingInstruction(QDomProcessingInstruction)")
    jobject x0 = __java_arguments[0].l;
    const QDomProcessingInstruction& __qt_x0 = qtjambi_cast<const QDomProcessingInstruction& >(__jni_env, x0);
    QDomProcessingInstruction *__qt_this = new(__qtjambi_ptr) QDomProcessingInstruction(__qt_x0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDomProcessingInstruction::QDomProcessingInstruction(QDomProcessingInstruction)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_initialize_1native__Lio_qt_xml_QDomProcessingInstruction_2Lio_qt_xml_QDomProcessingInstruction_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomProcessingInstruction::QDomProcessingInstruction(QDomProcessingInstruction)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomProcessingInstruction_cref_QDomProcessingInstruction, sizeof(QDomProcessingInstruction), typeid(QDomProcessingInstruction), false, &deleter_QDomProcessingInstruction, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomProcessingInstruction
void __qt_destruct_QDomProcessingInstruction(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomProcessingInstruction")
    reinterpret_cast<QDomProcessingInstruction*>(ptr)->~QDomProcessingInstruction();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomProcessingInstruction::data()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_data_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomProcessingInstruction *__qt_this = QtJambiAPI::objectFromNativeId<QDomProcessingInstruction>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomProcessingInstruction::data()const", __qt_this)
        QString __qt_return_value = __qt_this->data();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomProcessingInstruction::operator=(QDomProcessingInstruction)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_assign_1native_1cref_1QDomProcessingInstruction__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomProcessingInstruction *__qt_this = QtJambiAPI::objectFromNativeId<QDomProcessingInstruction>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomProcessingInstruction::operator=(QDomProcessingInstruction)", __qt_this)
        const QDomProcessingInstruction& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomProcessingInstruction>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomProcessingInstruction::setData(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_setData_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring d0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomProcessingInstruction *__qt_this = QtJambiAPI::objectFromNativeId<QDomProcessingInstruction>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomProcessingInstruction::setData(QString)", __qt_this)
        QString  __qt_d0 = qtjambi_cast<QString>(__jni_env, d0);
        __qt_this->setData(__qt_d0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomProcessingInstruction::target()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_target_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomProcessingInstruction *__qt_this = QtJambiAPI::objectFromNativeId<QDomProcessingInstruction>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomProcessingInstruction::target()const", __qt_this)
        QString __qt_return_value = __qt_this->target();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomProcessingInstruction *__qt_this = QtJambiAPI::objectFromNativeId<QDomProcessingInstruction>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomProcessingInstruction(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomProcessingInstruction>("QDomProcessingInstruction", "io/qt/xml/QDomProcessingInstruction");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDomProcessingInstruction, {
        ConstructorInfo(&__qt_construct_QDomProcessingInstruction, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomProcessingInstruction_cref_QDomProcessingInstruction, "Lio/qt/xml/QDomProcessingInstruction;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomProcessingInstruction);
    registerMetaType<QDomProcessingInstruction>("QDomProcessingInstruction");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-macos-6.7.1.jar: sources/QtJambiXml/QDomProcessingInstruction_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomProcessingInstruction(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomProcessingInstruction")
    QDomProcessingInstruction *_ptr = reinterpret_cast<QDomProcessingInstruction *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomProcessingInstruction()
void __qt_construct_QDomProcessingInstruction(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomProcessingInstruction()")
    Q_UNUSED(__java_arguments)
    QDomProcessingInstruction *__qt_this = new(__qtjambi_ptr) QDomProcessingInstruction();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomProcessingInstruction::QDomProcessingInstruction()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_initialize_1native__Lio_qt_xml_QDomProcessingInstruction_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomProcessingInstruction::QDomProcessingInstruction()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomProcessingInstruction, sizeof(QDomProcessingInstruction), typeid(QDomProcessingInstruction), 0, false, &deleter_QDomProcessingInstruction, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomProcessingInstruction(QDomProcessingInstruction)
void __qt_construct_QDomProcessingInstruction_cref_QDomProcessingInstruction(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomProcessingInstruction(QDomProcessingInstruction)")
    jobject x0 = __java_arguments[0].l;
    const QDomProcessingInstruction& __qt_x0 = qtjambi_cast<const QDomProcessingInstruction&>(__jni_env, x0);
    QDomProcessingInstruction *__qt_this = new(__qtjambi_ptr) QDomProcessingInstruction(__qt_x0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomProcessingInstruction::QDomProcessingInstruction(QDomProcessingInstruction)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_initialize_1native__Lio_qt_xml_QDomProcessingInstruction_2Lio_qt_xml_QDomProcessingInstruction_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomProcessingInstruction::QDomProcessingInstruction(QDomProcessingInstruction)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomProcessingInstruction_cref_QDomProcessingInstruction, sizeof(QDomProcessingInstruction), typeid(QDomProcessingInstruction), 0, false, &deleter_QDomProcessingInstruction, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomProcessingInstruction
void __qt_destruct_QDomProcessingInstruction(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomProcessingInstruction")
    reinterpret_cast<QDomProcessingInstruction*>(ptr)->~QDomProcessingInstruction();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomProcessingInstruction::data()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_data_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomProcessingInstruction *__qt_this = QtJambiAPI::objectFromNativeId<QDomProcessingInstruction>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomProcessingInstruction::data()const", __this_nativeId)
        QString __qt_return_value = __qt_this->data();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomProcessingInstruction::operator=(QDomProcessingInstruction)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_assign_1native_1cref_1QDomProcessingInstruction__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomProcessingInstruction *__qt_this = QtJambiAPI::objectFromNativeId<QDomProcessingInstruction>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomProcessingInstruction::operator=(QDomProcessingInstruction)", __this_nativeId)
        const QDomProcessingInstruction& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomProcessingInstruction>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomProcessingInstruction::setData(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_setData_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring d0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomProcessingInstruction *__qt_this = QtJambiAPI::objectFromNativeId<QDomProcessingInstruction>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomProcessingInstruction::setData(QString)", __this_nativeId)
        QString  __qt_d0 = qtjambi_cast<QString>(__jni_env, d0);
        __qt_this->setData(__qt_d0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomProcessingInstruction::target()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_target_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomProcessingInstruction *__qt_this = QtJambiAPI::objectFromNativeId<QDomProcessingInstruction>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomProcessingInstruction::target()const", __this_nativeId)
        QString __qt_return_value = __qt_this->target();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomProcessingInstruction_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomProcessingInstruction *__qt_this = QtJambiAPI::objectFromNativeId<QDomProcessingInstruction>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomProcessingInstruction(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomProcessingInstruction>("QDomProcessingInstruction", "io/qt/xml/QDomProcessingInstruction");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomProcessingInstruction, {
        ConstructorInfo(&__qt_construct_QDomProcessingInstruction, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomProcessingInstruction_cref_QDomProcessingInstruction, "Lio/qt/xml/QDomProcessingInstruction;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomProcessingInstruction);
    registerMetaType<QDomProcessingInstruction>("QDomProcessingInstruction");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
